@@ -17,3 +17,11 @@ After that, you can set config attributes:
 from . import init
 
 import my.config as config
+
+
+def set_repo(name: str, repo):
+    from .init import assign_module
+    from . common import import_from
+
+    module = import_from(repo, name)
+    assign_module('my.config.repos', name, module)
